package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````2R4```````!``````````%BQ````
M`````````$``.``,`$``&0`8``8````$````0`````````!``````````$``
M````````H`(```````"@`@````````@``````````P````0```#@`@``````
M`.`"````````X`(````````9`````````!D``````````0`````````!````
M!````````````````````````````````````!@8````````&!@`````````
M$`````````$````%`````"``````````(``````````@````````&3,`````
M```9,P`````````0`````````0````0`````8`````````!@`````````&``
M```````X1````````#A$`````````!`````````!````!@```#"L````````
M,+P````````PO````````#`$````````\!0`````````$`````````(````&
M````6*P```````!8O````````%B\````````H`$```````"@`0````````@`
M````````!`````0``````P`````````#``````````,````````P````````
M`#``````````"`````````!3Y71D!``````#``````````,``````````P``
M`````#``````````,``````````(`````````%#E=&0$````;)X```````!L
MG@```````&R>````````Y`````````#D``````````0`````````4>5T9`8`
M````````````````````````````````````````````````````````$```
M``````!2Y71D!````#"L````````,+P````````PO````````-`#````````
MT`,````````!`````````"]L:6(O;&0M;75S;"UX.#9?-C0N<V\N,0``````
M````!````"`````%````1TY5``$``<`$`````0`````````"``'`!`````$`
M````````$0```#X````$````"````"`<$``%0`2"*`!0!)"&`(2"(0`@20($
M";B"&4&Z!`(*/@```#\```!#````1P```$@```!.````3P```%$`````````
M50```%8```!7````60```%L```!=``````````````"CZ1D$:G^:?.K3[P[.
MWD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'
MQ@&[XY)\5<,\TL2YG$!GK\QF./*+',2)!9"(!W#30T75[#-BV^T5C"7,5J2;
MEJ?=HVM^J9R;T67.;>"G`@IK&IY0"HH05Z/@^TD`````````````````````
M```````````!````$@````````````````````````!1`0``$@``````````
M```````````````0````$@````````````````````````".`0``$@``````
M```````````````````8````$@`````````````````````````?````$@``
M``````````````````````#"`0``$@````````````````````````":`0``
M$@`````````````````````````H````(`````````````````````````!`
M````$@````````````````````````!&````$@``````````````````````
M``!-````$@````````````````````````">`@``$@``````````````````
M``````"/`@``$@````````````````````````#H`0``$@``````````````
M``````````!4````$@````````````````````````!N`@``$@``````````
M``````````````!;````$@````````````````````````!C````$@``````
M``````````````````!7`@``$@````````````````````````!K````$@``
M``````````````````````!Q````$@````````````````````````!Z````
M(`````````````````````````"(`@``$@````````````````````````"6
M````$@````````````````````````";````$@``````````````````````
M``!U`@``$@`````````````````````````5`@``$@``````````````````
M``````"B````$@`````````````````````````'`@``$@``````````````
M```````````6`P``$@`````````````````````````Y`@``$@``````````
M``````````````"]`@``$@````````````````````````"I````$@``````
M``````````````````"U`@``$@````````````````````````!?`0``$@``
M``````````````````````#!````(`````````````````````````#7````
M$@````````````````````````"``@``$@`````````````````````````E
M`@``$@````````````````````````#<````$@``````````````````````
M``#B````(`````````````````````````!B`@``$@``````````````````
M``````#\````$@````````````````````````!_`0``$@``````````````
M```````````!`0``$@````````````````````````!'`@``$@``````````
M``````````````!N`0``$@`````````````````````````'`0``$@``````
M```````````````````8`0``$@````````````````````````#C`0``$@``
M``````````````````````!L````$@````````````````````````#T`0``
M$@`````````````````````````N`@``$@````````````````````````"N
M`@``$@`````````````````````````>`0``$@``````````````````````
M``"F`@``$@````````````````````````#>`0``$@``````````````````
M```````R`0``$@`````````````````````````Y`0``$@``````````````
M``````````!*`0``$@````````````````````````#/`@``(0`6`(#`````
M````"`````````#*`@``$@`+`*`C````````JP$```````"O`0``$@`,`!%3
M`````````0````````!8`P``$@`+`*XQ````````Q@4````````$!```$@`+
M`+`Y````````3P`````````U`P``$@`+`,$L````````!0````````#"`P``
M$@`(```@`````````0````````![`P``$@`+`'0W````````/`(```````#H
M`P``$@`+`,8L````````H`$```````"S`P``$``6`&#`````````````````
M``!&`P``$@`+`"0Q````````B@````````!E`P``$@`+`&<K````````*P``
M``````!M`P``$@`+`,4P````````2`````````"1`P``$@`+`'%0````````
M]P````````"F`P``$@`+`&8N````````%@````````#_`P``$``6`"#1````
M``````````````#[`@``$@`+`&$E````````)`````````#0`@``$0`6`(#`
M````````"`````````#(`P``$@`+`'PN````````J@`````````)````$0`2
M`%"\````````"`````````#1`@``(0`6`(#`````````"`````````"<`P``
M$0`5`%C`````````"`````````#A`P``$``5`&#```````````````````"X
M`P``$``+`$LE``````````````````"_`P``$@`+`"-0````````3@``````
M``#3`0``$0`6`(C`````````!`````````#2`@``(0`6`(#`````````"```
M```````$`P``$@`+``TQ````````%P````````"R````(@``````````````
M```````````?`P``$@`+`-8K````````ZP````````#U`P``$@`+`&A1````
M````60$```````"U`0``$0`6`&#``````````0````````#4`P``$@`+`"8O
M````````GP$`````````;W!E;F1I<@!S=&1E<G(`<F5A;&QO8P!A8V-E<W,`
M<VYP<FEN=&8`7U]D97)E9VES=&5R7V9R86UE7VEN9F\`;'-E96L`9V5T<&ED
M`'-T<F-M<`!U;FQI;FL`;65M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E9&ER
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!S=')C
M:'(`<F5A9&QI;FL`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]F<F%M95]I
M;F9O`&5X:70`8VQO<V4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!R96%D
M`')M9&ER`%]?97)R;F]?;&]C871I;VX`;6MD:7(`<'1H<F5A9%]G971S<&5C
M:69I8P!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?
M=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N
M<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%]F:6YI
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S
M869E<WES;6%L;&]C`'!E<FQ?86QL;V,`9G!R:6YT9@!S=')D=7``<'1H<F5A
M9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB
M8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM
M>#@V7S8T+G-O+C$`7W-T87)T7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U
M:60`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R
M7W-E='5P7VQI8G!A=&@`<&%R7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C
M;&5A;@!84U]);G1E<FYA;'-?4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?
M<&P`<&%R7V)A<V5N86UE`%]?8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N
M86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA
M;`!?96YD`'!A<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#
M3U)%`````,`````````(``````````#`````````(,`````````(````````
M``!@````````*,`````````(`````````/)@````````,,`````````(````
M``````M@````````.,`````````(``````````1A````````0,`````````(
M`````````!-@````````6,`````````(`````````+9B````````P+\`````
M```&````"0``````````````R+\````````&````%P``````````````T+\`
M```````&````6@``````````````V+\````````&````)0``````````````
MX+\````````&````*@``````````````Z+\````````&````+P``````````
M````\+\````````&````,```````````````^+\````````&````-0``````
M````````4+P````````%````40``````````````8,`````````%````70``
M````````````@,`````````%````3P``````````````B,`````````%````
M5P``````````````$+X````````'`````0``````````````&+X````````'
M`````@``````````````(+X````````'`````P``````````````*+X`````
M```'````!```````````````,+X````````'````!0``````````````.+X`
M```````'````!@``````````````0+X````````'````!P``````````````
M2+X````````'````"```````````````4+X````````'````"@``````````
M````6+X````````'````"P``````````````8+X````````'````#```````
M````````:+X````````'````#0``````````````<+X````````'````#@``
M````````````>+X````````'````#P``````````````@+X````````'````
M$```````````````B+X````````'````$0``````````````D+X````````'
M````$@``````````````F+X````````'````$P``````````````H+X`````
M```'````%```````````````J+X````````'````%0``````````````L+X`
M```````'````%@``````````````N+X````````'````&```````````````
MP+X````````'````&0``````````````R+X````````'````&@``````````
M````T+X````````'````&P``````````````V+X````````'````'```````
M````````X+X````````'````'0``````````````Z+X````````'````'@``
M````````````\+X````````'````'P``````````````^+X````````'````
M(````````````````+\````````'````(0``````````````"+\````````'
M````(@``````````````$+\````````'````(P``````````````&+\`````
M```'````)```````````````(+\````````'````)@``````````````*+\`
M```````'````)P``````````````,+\````````'````*```````````````
M.+\````````'````*0``````````````0+\````````'````*P``````````
M````2+\````````'````+```````````````4+\````````'````+0``````
M````````6+\````````'````+@``````````````8+\````````'````,0``
M````````````:+\````````'````,@``````````````<+\````````'````
M,P``````````````>+\````````'````-```````````````@+\````````'
M````-@``````````````B+\````````'````-P``````````````D+\`````
M```'````.```````````````F+\````````'````.0``````````````H+\`
M```````'````.@``````````````J+\````````'````.P``````````````
ML+\````````'````/```````````````N+\````````'````/0``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!0Z*H&``#HQ3(``%C#````_S7JG0``_R7LG0``#Q]``/\EZIT``&@`````
MZ>#_____)>*=``!H`0```.G0_____R7:G0``:`(```#IP/____\ETIT``&@#
M````Z;#_____)<J=``!H!````.F@_____R7"G0``:`4```#ID/____\ENIT`
M`&@&````Z8#_____);*=``!H!P```.EP_____R6JG0``:`@```#I8/____\E
MHIT``&@)````Z5#_____)9J=``!H"@```.E`_____R62G0``:`L```#I,/__
M__\EBIT``&@,````Z2#_____)8*=``!H#0```.D0_____R5ZG0``:`X```#I
M`/____\E<IT``&@/````Z?#^____)6J=``!H$````.G@_O___R5BG0``:!$`
M``#IT/[___\E6IT``&@2````Z<#^____)5*=``!H$P```.FP_O___R5*G0``
M:!0```#IH/[___\E0IT``&@5````Z9#^____)3J=``!H%@```.F`_O___R4R
MG0``:!<```#I</[___\E*IT``&@8````Z6#^____)2*=``!H&0```.E0_O__
M_R4:G0``:!H```#I0/[___\E$IT``&@;````Z3#^____)0J=``!H'````.D@
M_O___R4"G0``:!T```#I$/[___\E^IP``&@>````Z0#^____)?*<``!H'P``
M`.GP_?___R7JG```:"````#IX/W___\EXIP``&@A````Z=#]____)=J<``!H
M(@```.G`_?___R72G```:",```#IL/W___\ERIP``&@D````Z:#]____)<*<
M``!H)0```.F0_?___R6ZG```:"8```#I@/W___\ELIP``&@G````Z7#]____
M):J<``!H*````.E@_?___R6BG```:"D```#I4/W___\EFIP``&@J````Z4#]
M____)9*<``!H*P```.DP_?___R6*G```:"P```#I(/W___\E@IP``&@M````
MZ1#]____)7J<``!H+@```.D`_?___R5RG```:"\```#I\/S___\E:IP``&@P
M````Z>#\____)6*<``!H,0```.G0_/___R5:G```:#(```#IP/S___\E4IP`
M`&@S````Z;#\____)4J<``!H-````.F@_/___R5"G```:#4```#ID/S___\E
M.IP``&:0_R5"G```9I#_)4*<``!FD```````````051(@^P@B7PD'$B-?"0<
M2(ET)!!(C70D$$B)5"0(2(U4)`CH:/[__TB+-2F<``!(BST:G```2(GRZ`+]
M__^`/7N<````=37HM/W__TB)!26M``!(B<=(A<!U"K\!````Z#O^___HEO[_
M_XL]>)P``.@+____QH#7"0```(L]9IP``.CY_O__BSU;G```@(@J!````NCG
M_O__BWPD'("(*@0```%$C6<#@\<$2&/_2,'G`^@I_O__2(MT)!"+?"0<2(G!
M2(D%IJP``$B+!DB)`4B-!3D^``!(B4$(2(L%UIL``$B)01!(C04F/@``2(E!
M&#'`C5`$2/_`2&/22(T4T3G'?@E,BP3&3(D"Z^9(QP(`````13'`1(GB2(L]
M5ZP``$B--<H&``#H<_S__T&)Q(7`=0](BST]K```Z(#]__]!B<1(BSTNK```
MZ`']__\QP$B-/;0[``#H<0(``$B%P'4N2(,]_JL```!U$TB-/4X[``#H5@(`
M`$B)!>FK``!(BSWBJP``2(7_=`7H@!0``$B+/>&K``#H!/[__^CO^O__2(/$
M($2)X$%<PT@Q[4B)YTB--0"7``!(@^3PZ`````!(BS=(C5<(13')3(T%GRT`
M`$B-#8?Z__](C3T@_O__Z7O\__]F+@\?A```````D$B-/<F:``!(C07"F@``
M2#GX=!5(BP4>F@``2(7`=`G_X`\?@`````###Q^``````$B-/9F:``!(C362
MF@``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!?69``!(A<!T"/_@9@\?1```
MPP\?@`````"`/9F:````#X63````54B#/;J9````2(GE0513=`Q(BSW;F0``
MZ%[]__](C04/E@``2(T=$)8``$@IPTF)Q$B+!6.:``!(P?L#2(/K`4@YV',A
M9@\?1```2(/``4B)!46:``!!_Q3$2(L%.IH``$@YV'+EZ!C___](@SU`F0``
M`'0,2(T]'WD``.CR_/__6T%<Q@4(F@```5W#9@\?1```PV9F+@\?A```````
M#Q]``$B#/2"9````="952(TU_ID``$B-/=]X``!(B>7HO_S__UWIZ?[__V8/
M'X0``````.G;_O__05=!5D%5051%,>154U%(A?]T9TR+-8&9``!-A?9T6TF)
M_4F)]TB)^(H0A-)T"H#Z/70%2/_`Z_!$*>A,B?5(8]A,BV4`387D=#!(B=I,
MB>Y,B>?H\_G__X7`=1A!@#P</7413"GU38UD'`%(P?T#08DOZP9(@\4(Z\=:
M3(G@6UU!7$%=05Y!7\-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z%G___](
MBU0D"&1(*Q0E*````'0%Z+_[__](@\08PU532(G[2(/L&&1(BP0E*````$B)
M1"0(,<!(C6PD!#'`2(GN2(G?Z!3___](A<!T(DAC5"0$2(L%GI@``$B-!-!(
MBU`(2(D02(72=-)(@\`(Z^Y(BT0D"&1(*P0E*````'0%Z%/[__](@\086UW#
M059!54%455-(@>R@````9$B+!"4H````2(F$))@````QP$B%_P^$X@```(`_
M`$B)_0^$U@```.C0]___2(U<)`A)B<5(A<`/A,````!,B>_H9_C__TB%P`^$
MGP```$R-8!-(C36;-P``3(GGZ#OX__^%P'382(TUAS<``$R)Y^@H^/__A<!T
MQ4B)[^BL^O__3(GG28G&Z*'Z__]!C7P&`DAC_^A4^/__3(GA2(GJ2(TU43<`
M`$F)QDB)QS'`Z%KZ__],B?=(B=[H#_K__TR)]__`=!>+1"0@)0#P```]`$``
M`'4'Z!?____K!>C\]___3(GWZ-3Y___I4/___TR)[^A'^/__2(GOZ(_Y__](
MBX0DF````&1(*P0E*````'0%Z"?Z__](@<2@````6UU!7$%=05[#2('LN```
M`&1(BP0E*````$B)A"2H````,<!(C70D&$B)?"0(Z-[W__^%P'4SBU0D,$B+
M?"0(@>(`\```@?H`0```=`B!^@"@``!U%KX"````Z,'V__^%P`^4P`^VP.L"
M,<!(BXPDJ````&1(*PPE*````'0%Z)WY__](@<2X````PT%6055!5%5(B?U3
M2(GS2(/L$&1(BP0E*````$B)1"0(,<"`/CUU`TC_PTB)W^A3^?__2(UT)`1(
MB>])B<0QP.C6_/__28G%2(7`="=(B<?H,?G__TDYQ`^'J````#'`BA0#08A4
M!0!(_\"$TG7QZ0<!``!,BS4[E@``,<!!B<5(_\!)@WS&^`!U\D&-=0)(8_9(
MP>8#@SV9I@```'093(GWZ,_U__](B04(E@``2(7`=3GIPP```,<%=*8```$`
M``!(B??H?/;__TB%P`^$J````$ECU4R)]DB)QTC!X@/H<?;__TB)!<J5``!(
MBQ7#E0``08U%`4B82,<$P@````!$B6PD!$B)Z(H0A-)T"H#Z/70%2/_`Z_!(
M*>A(8TPD!$B+%8Z5``!(F$F-?`0"3(TLRN@.]O__28E%`$B%P'0Z2&-4)`1(
MBP5IE0``2(L$T(I5`$C_Q4B)P4C_P(A0_X32=`6`^CUUZ,8!/3'2B@P3B`P0
M2/_"A,EU\TB+1"0(9$@K!"4H````=`7H!OC__TB#Q!!;74%<05U!7L-0BST:
ME0``Z*WW__](BQ5NE```05A(C0W=<@``2(G'2(TUDS0``.EN]___4(L][Y0`
M`.B"]___2(G'Z,'___^+/=R4``#H;_?__TR-!?<V``!%,<E!6DB)QTR)P4B-
M%:H+``!(C35K-```Z:KT__]!5%532('L$"```&1(BP0E*````$B)A"0((```
M,<!,C60D!NBR]/__3(T%3#0``+X!$```3(GGB<%(C14_-```,<#H4_3__X/X
M_W4$,<#K=TACT$B!^@`0``!V`@\+A<!XZDB-K"0'$```N@`0``!,B>=(B>[H
MP/7__TB)PX7`>,N->`%(8__HKO3__TB%P'2[2&/32#GH<PE(C0P02#G-<KI(
M.>AV"DB-3!4`2#G(<JN!^P$0``!_HXG12(G'2(GN\Z3&!!``2(NT)`@@``!D
M2"LT)2@```!T!>BK]O__2('$$"```%M=05S#Z1#___]!5T%6055)B?U(C3V+
M,P``05152(GU4TB![*@0``!D2(L$)2@```!(B80DF!```#'`Z'+Z__^^+P``
M`$R)[TB)P^BT]/__2(7`=!9,B>Y(C3U/,P``,<#HJ?S__^D2`0``3(GO3(T]
MYS(``.@:]O__2(TU.C,``$B)[T&)QNC(]?__28G$387D=,%!@#PD`'4#38G\
M2(7;=!-,B>9(B=_H5O/__X7`#X2Q````3(GGZ-;U__^-2/](8]%,`>*`.B]U
M!\8"`(G(Z^M"C40P`3W_#P``#X]R____2(VL))@```!-B>E,B>$QP$R-!<,R
M``!(C16@,P``O@`0``!(B>_HIO+____`/0`0``!V`@\+2(UT)`A(B>_H#O7_
M_X7`=3V+1"0@)0#P```]`(```'4MO@$```!(B>_H7?+__X7`=1Q(B>Y(C3U9
M,@``Z+7[__](B>_H4O/__TF)Q>L62(TU33(``#'_Z-_T__])B<3I$O___TB+
MA"28$```9$@K!"4H````=`7H#_7__TB!Q*@0``!,B>A;74%<05U!7D%?PTB)
M^(H7A-)T#$C_QX#Z+T@/1,?K[L-(A?\/A)4```!5@#\`2(G]=#SHO?3__TB-
M5`7_2#G5<QN`.B]U$4C_RNOQ@#HO2(U"_W0I2(G"2#G5<N](.=5U'(!]`"](
MC3VQ,0``=0=(C3U',0``7>M-@#HO=0A(_\I(.=5R\T@IZDB-0@)(/0`0``!W
M)DC_PDB!^@`0``!V`@\+2(GN2(T]^)$``.@3\___2(T%[)$``.L",<!=PTB-
M/?<P``#I2O+__TB#[#A(C34';P``N2(```!D2(L$)2@```!(B40D*#'`2(U\
M)`;SI$B-/2<Q``#H3?C__S'`2(T](C$``.@_^/__,<!(C3T<,0``Z#'X__\Q
MP$B-/1<Q``#H(_C__S'`2(T]$#$``.@5^/__,<!(C3T2,0``Z`?X__\QP$B-
M/;DP``#H^??__S'`2(T]`C$``.CK]___,<!(C3W^,```Z-WW__\QP$B-/?HP
M``#HS_?__S'`2(T]BC```.C!]___,<!(C3WH,```Z'OW__](A<!T$4B)QDB-
M/<`P```QP.C"^?__2(T]US```#'`Z%?W__](B<9(A<!T#DB-/=HO```QP.B>
M^?__2(T]Q3```#'`Z#/W__](C3T?,```2(G&2(7`=1U(C3VX,```,<#H%O?_
M_TB)QDB%P'0+2(T]43```#'`ZR9(C7PD%[H*````2(TUGC```.BO\/__A<!U
M$4B-="0A2(T])S```.@U^?__,<!(C36&,```2(T]]B\``.@@^?__2(M$)"AD
M2"L$)2@```!T!>B@\O__2(/$.,.#/82/``#_=3A12(T]XB\``#'`Z)'V__](
MB<(QP$B%TG01BA*`^C`/E<$QP(32#Y7`(<B)!5*/``"+!4R/``!:PXL%1(\`
M`,-1Z%WR__^)Q^C&\/__2(7`=`-(BP!:PT%4,<!)B?Q(C3WU+P``55/H-?;_
M_TR)YDB%P'16@#@`2(G#=$Y(B<?H/_#__TB%P'533(GGZ/+Q__](B=](B<7H
MY_'__TB-?`4"Z)WO__](C37C+P``28G83(GB2(G%2(G'2(T-ZBX``#'`Z)SQ
M__](B>Y;2(T]B"\``%TQP$%<Z2+X__];74%<PT%72(TU:8X``+D,````059!
M54%455-(B?M(@>Q8@0``9$B+!"4H````2(F$)$B!``!(C058+P``2(U\)$A(
MQT0D*`````#SI4B-/60N``!(QT0D0`````!(B40D&$B-!08N``!(B40D($B-
M!24O``!(B40D,$B-!1XO``!(B40D.#'`Z#CU__](A<!T0(`X`$B)Q70X2(G'
MZ-G^__](BX0D2($``&1(*P0E*`````^%^`0``$B!Q%B!``!(B>];74%<05U!
M7D%?Z?7N__\QP$B-;"0PZ(;^__])B<1(A<!U.4B+?0!(A?]T*3'`Z,_T__](
MB<=(A<!U!DB#Q0CKXH`X`'3UZ+GN__])B<1(A<!TZ.L'3(TE;RX``$R)YTR-
M+7\N``#H>?#__TB-?``!Z"_N__])B<9(B<5!#[84)(32=!9(B>],B>XQP$G_
MQ.@P\/__2(/%`NOA3(UL)$A-BV4`387D="Y,B><QP.A0]/__2(G%2(7`=".`
M.`!T'DB)Q^@6]O__A<!T$DB)[^@Q[O__28G$3(UL)!CK,$F#Q0CKO$F+;0!(
MA>UT)H!]``!T($B)[^CC]?__A<!T"TB)[^C^[?__28G$28/%"$V%Y'313(GG
MZ,KO__],B?=(B<7HO^___XVL!00$``!(8^U(B>_H;>W__TV)\4R-!:DM``!(
MC0W%+```2(G'28G%3(GB,<!(C365+0``Z&7O__^^P`$``$R)[^CX[O___\!U
M*^C?[O__1(L`08/X$70=2(L32(L]7(@``$R)Z3'`2(TU9"T``.A+[O__ZR](
MC70D>$R)[^@\[?__08G&A<!T(TB+$TB+/2N(``!,B>DQP$B--6XM``#H&N[_
M_T4QY.D)`P``BX0DD````"4`\```/0!```!URD2+I"24````Z!+O__]!.<1U
MN(N$))`````E_P$``#W``0``=:5(B>_HDNS__TB-/:TL``!)B<0QP.C?\O__
M2(G'2(7`=05(BROK&.C/[/__2(L[2(G&Z!KX__](B<5(A<!TXTB)[^B4[O__
M28G'@_@#?EI(F$B--24M``!(C7P%_.CIZ___A<!U0T&#_P1T#T&#[P5-8_]"
M@'P]`"]U+DB+6PA(A=MT)4B)W^A/[O__2(/X`W872(U\`_Q(C37D+```Z*CK
M__^%P$@/1.LQP.B@^___A<`/A6D!``!(B>\Q]NA)[/__B<6%P`^$50$``+H"
M````2,?&[O___XG'Z$SK__](C9PD2`$``+H&````B>](B=[H)>W__X"\)$@!
M````=6.`O"1)`0``0W59@+PD2@$``$%U3X"\)$L!``!#=46`O"1,`0``2'4[
M@+PD30$``$5U,;H"````2,?&QO___XGOZ.;J__^Z*0```$B)WHGOZ,?L__],
MC0W?+```28G8Z9X````QTC'VB>_HO>K__S'`Z#D:``!)B<:Z`(```$B)WHGO
MZ)3L__](B<*%P'X-2(G>3(GWZ&,:``#KW8GO3(V\)`L!``!(C:PD'P$``#';
MZ$?L__],B?9,B?],C34;*P``Z"T;``!)B>A!#[84'TB)[S'`3(GV2/_#3(E$
M)`A(@\4"Z-3L__](@_L43(M$)`AUU\:$)$<!````3(T-.2P``$B-#?PI``!,
MB>I,B><QP$B--7`K``#HG^S__^F0````2(TUB"H``$B-/10J```QP.@@\___
M2(T=_2L``.CYZ?__3(T-\2L``$R)ZDB-#;$I``!!B<!(C34Y*P``3(GG,<#H
M5.S__[[``0``3(GGZ.?K____P'4YZ,[K__^#.!%U+^BTZ?__0?_&3(GJ3(GG
M08G`4#'`2(T-9RD``%-%B?%(C37\*@``Z`[L__]:6>NV3(GOZ++K__](C3TL
M*0``3(GF,<#HC/+__TR)Y^C=^?__2(N$)$B!``!D2"L$)2@```!T!>@![/__
M2('$6($``$R)X%M=05Q!74%>05_#052+/0R)``!54^B=Z___BSW_B```2(G#
MZ(_K__^*D[````!(C3W^*```B)"Q````,<#HP^___TB%P'0+@#@Q=0:`>`$`
M=`<QP.AD]___BSW`B```Z%/K__^Y`P```+H!````2(TU3"H``$B)Q^C*Z?__
M2(G#2(7`=$=(BT`0BSV0B```2(LHZ"#K__](C14E*@``2(G'2(GNZ+[I__](
MBT,02(LH]D4.0'06BSUCB```Z/;J__](B>Y(B<?HN^C__XL]38@``.C@ZO__
MN0,```"Z`0```$B-->`I``!(B<?H5^G__TB)PTB%P'1\2(T]`B@``#'`Z/_N
M__])B<1(A<!T#TB+0Q"+/0>(``!(BRCK1.A+\___BSWWAP``2(7`2(G%2(M#
M$'0@3(L@Z'OJ__](B>I(B<=,B>;H'>G__TB)[^@EZO__ZR!(BQ5,F```2(LH
M3(LBZ%'J__],B>)(B>Y(B<?H\^C__XL]I8<``.@XZO__N@$```!(C34_*0``
M2(G'Z%3G__^+/8:'``!(B<7H%NK__TB-%3<I``!(B>Y(B<?HM.C__XL]9H<`
M`.CYZ?__2(T],R<``,:`L0`````QP.@R[O__2(D%Q9<``$B%P'4D2(L]P9<`
M`.A:^/__2(D%K9<``$B%P'4,2(T]YR@``.@DY___2(L]E9<``+[``0``Z%/I
M__^)P8U``8/X`78D@_D1=!](BP5]EP``2(L5;I<``$B-/<XH``!(BS`QP.CE
MYO__6UU!7,-52(G]4U'HP?3__TB)Q^BC]/__2(G#,<#H^/;__X7`="I(A>UT
M)8!]``!T'TB--7,G``!(B=_HI>?__T@YPW4+6DB)[UM=Z1GN__]86UW#05<Q
MTD%6055!5%532('LF`(``&1(BP0E*````$B)A"2(`@``,<"+1!<X2(MT%S@/
MR(G`2(GQ2(E$5`A(B?!(P>D@2,'H*$C![C@E`/\``$@)\$B)SDC!X0A(P>88
M@>$``/\`B?9("?!("<A(B414$$B#P@A(@_I`=:Q(C50D"$B-M"0(`@``2(M"
M:$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'PG(2(E">$@Y\G793(L/3(M?$$B+
M=R!(BU\83(G(3(G*2(MO"$C!ZAM(P>`%2`G0`T0D"(V4,)EY@EI,B=A(BW0D
M$$@QV$@AZ$B-M#.9>8):2#'81(TD`DB)ZDB)Z$C!Z`)(P>(>38G@2`G"3(G8
M2<'H&XG12#'(3"'(3#'82`'P3(GF2,'F!4P)QD2--#!,B<Y,B<A(P>8>2,'H
M`DV)\D@)\$B+="082<'J&T@QPD&)P$PAXDF-M#.9>8):2#'*2`'R3(GV2,'F
M!4P)UD2-%#),B>9)P>P"2(M4)"!(P>8>3`GF2(V4$9EY@EI,B=%(,?!!B?5,
M(?!,,<!(P>D;2`'03(G22,'B!4@)RDR)\4G![@)(P>$>1(TD$$B+1"0H3`GQ
M3(GB2#'.28V$`)EY@EI(P>H;08G.3"'63#'N2`'&3(G@2,'@!4@)T$R)TDG!
MZ@)(P>(>1(T$!DB+1"0P3`G23(G&2#'128V$!9EY@EI(P>X;08G23"'A3#'Q
M2`'!3(G`2,'@!4@)\$2-+`%,B>!)P>P"2(M,)#A(P>`>3(GN3`G@28V,#IEY
M@EI(,<)!B<1,(<),,=)(`<I,B>E(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TT
M"DB+5"1`3`G&3(GQ2#'P28V4$IEY@EI(P>D;08GP3"'H3#'@2`'03(GR2,'B
M!4@)RDR)Z4G![0)(P>$>1(T4$$B+1"1(3`GI3(G22#'.28V$!)EY@EI(P>H;
M08G-3"'V3#'&2`'&3(G02,'@!4@)T$R)\DG![@)(P>(>1(TD!DB+1"103`GR
M3(GF2#'128V$`)EY@EI(P>X;08G63"'13#'I2`'!3(G@2,'@!4@)\$2-!`%,
MB=!)P>H"2(M,)%A(P>`>3(G&3`G028V,#9EY@EI(P>X;2#'"08G"3"'B3#'R
M2`'*3(G!2,'A!4@)\4R)YDG![`)(P>8>1(TL"DB+5"1@3`GF3(GI2#'P28V4
M%IEY@EI(P>D;08GT3"'`3#'02`'03(GJ2,'B!4@)RDR)P4G!Z`)(P>$>1(TT
M$$B+1"1H3`G!3(GR2#'.28V$`IEY@EI(P>H;08G(3"'N3#'F2`'&3(GP2,'@
M!4@)T$R)ZDC!XAY)P>T"1(T4!DB+1"1P3`GJ3(G62#'128V$!)EY@EI(P>X;
M08G53"'Q3#'!2`'!3(G02,'@!4@)\$2-)`%,B?!)P>X"2(M,)'A(P>`>3(GF
M3`GP28V,")EY@EI(P>X;2#'"08G&3"'23#'J2`'*3(GA2,'A!4@)\4R)UDG!
MZ@)(P>8>1(T$"DB+E"2`````3`G63(G!2#'P28V4%9EY@EI(P>D;08GR3"'@
M3#'P2`'03(G"2,'B!4@)RDR)X4G![`)(P>$>1(TL$$B+A"2(````3`GA3(GJ
M2#'.28V$!IEY@EI(P>H;08G,3"'&3#'62`'&3(GH2,'@!4@)T$R)PDG!Z`)(
MP>(>1(TT!DB+A"20````3`G"3(GV2#'128V$`IEY@EI(P>X;08G03"'I3#'A
M2`'!3(GP2,'@!4@)\$2-%`%,B>A)P>T"2(N,))@```!(P>`>3`GH28V,#)EY
M@EI-B=1(,<))P>P;B<9,(?),,<)(`=%,B=)(P>(%3`GB38GT2<'N`DG!Y!Z)
MTDT)]$@!RDB+C"2@````3#'@08G53"'028V,")EY@EI-B>A(,?!)P>@;2`'!
M3(GH2,'@!4P)P(G`2`'(3(G12<'J`DC!X1Y!B<!,"=%-B>)%B>1,`Z0DL```
M`$DQRD0QTDR+E"2H````2HVT%J'KV6Y-B<)(`?),B<9)P>H;2,'F!4P)UDV)
MZDG![0))P>(>B?9-">I)B<U(`?*)R4TQU8G62`.,)+@```!$,>A)B?5-C:0$
MH>O9;DB)\$G![1M(P>`%3`GHB<!-C2P$3(G`2<'H`DC!X!Y%B>Q,"<!-B=!%
MB=)),<!$,<),C801H>O9;DR)XDR)X4C!X@5(P>D;3`.4),````!("<J)TDF-
M#!!)B?!(P>X"2<'@'HG*20GP2(G&B<!(`X0DR````$PQQD$Q]4B)UD^-E"JA
MZ]EN28G52,'F!4G![1M,">Z)]DV-+#),B>9)P>P"2,'F'D6)ZDP)YDV)Q$6)
MP$P#A"30````23'T1#'A38G42(V,"*'KV6Y,B=!)P>P;2,'@!4P)X(G`2`'(
M2(G12,'J`DC!X1Y!B<1("=%(B?*)]D@QRD$QU4R)XD^-K"BAZ]EN38G@2,'B
M!4G!Z!M,"<*)TDV-1!4`3(G22,'B'DG!Z@)%B<5(`[0DV````$P)TDF)RHG)
M2`.,).````!),=)$,=!,C90&H>O9;DR)Z$R)[DC![AM(P>`%2`GPB<!)C30"
M3(G@2<'L`DC!X!Y!B?),">!)B=2)TD@#E"3H````23'$13'@38G43HV$`:'K
MV6Y,B=%)P>P;2,'A!4P)X8G)3`'!38GH2<'M`DG!X!Y!B<Q-">A)B<6)P$@#
MA"3P````33'%1#'N38GE2(VT,J'KV6Y,B>))P>T;2,'B!4P)ZHG22`'R3(G6
M2<'J`DC!YAY!B=5,"=9-B<)%B<!),?),`X0D^````$0QT4V)ZDB-C`BAZ]EN
M3(GH2<'J&TC!X`5,"=")P$@!R$R)X4G![`)(P>$>08G"3`GA28GTB?9(`[0D
M``$``$DQS$0QXDV-I!"AZ]EN3(G238G02<'H&TC!X@5,"<*)TDV-!!1,B>I)
MP>T"2,'B'D6)Q$P)ZDF)S8G)2`.,)`@!``!),=5$,>A,C:P&H>O9;DR)X$R)
MYDC![AM(P>`%2`GPB<!)C70%`$R)T$G!Z@)(P>`>08GU3`G028G2B=)),<)%
M,=!-B>I.C80!H>O9;DR)Z4G!ZAM(P>$%3`G12`.4)!`!``")R4P!P4V)X$G!
M[`))P>`>08G*30G@28G$B<!(`X0D&`$``$TQQ$0QYDV)U$B-M#*AZ]EN3(G2
M2<'L&TC!X@5,">*)TD@!\DR)[DG![0)(P>8>08G43`GN38G%18G`3`.$)"`!
M``!),?5$,>E-B>5(C8P(H>O9;DR)X$G![1M(P>`%3`GHB<!(`<A,B=%)P>H"
M2,'A'D&)Q4P)T4F)\DV)[HGV23'*2<'N&T0QTDV-A!"AZ]EN3(GJ2,'B!4P)
M\HG238TT$$R)XDF)R(G)2,'B'DG![`)%B?)(`[0D*`$``$P)XDV)U$@#C"0P
M`0``23'02<'L&T0QP$B-M`:AZ]EN3(G02,'@!4P)X(G`3(TD!DR)Z$G![0)(
MB=9(P>`>18G@B=)(`Y0D.`$``$P)Z$V)Q4@QQDG![1M!,?9*C;0QH>O9;DR)
MP4C!X05,">F)R4R-+`Y,B=%)P>H"2,'A'D2)[DP)T4F)PHG`2`.$)$`!``!)
M,<I%,=1.C90BH>O9;DB)\DF)]$G![!M(P>(%3`GB38G$2<'H`DG!Y!Y!`=)-
M"<1)B<B)R4TQX$2)XD4QQ4Z-A"BAZ]EN3(G038G52<'M&TC!X`5,">A,BZPD
M2`$``$6--`!)B?!(P>X"3(G@2<'@'DD)\$2)QDP)P$PAT$DA]$D)Q+C<O!N/
M20'%3`'I38GU20',3(GQ2<'M&TC!X05,">E%C2P,3(G12<'J`DC!X1Y,"=%)
M"<A)B<Q!B<I)(?1-(?!-">!,BZ0D4`$``$D!Q$P!XDV)[$D!T$R)ZDG![!M(
MP>(%3`GB18TD$$R)\DG![@)(P>(>3`GR28G.08G020G632'N3"'!3`GQ3(NT
M)%@!``!)`<9,`?9-B>9(`?%,B>9)P>X;2,'F!4P)]D2--#%,B>Y)P>T"2,'F
M'DP)[D@)\DF)]8GQ3"'B32'%3`GJ3(NL)&`!``!)`<5-`>I-B?5,`=)-B?))
MP>T;2<'B!4T)ZD:-+!)-B>))P>P"2<'B'DT)XDF)]$2)TDT)U$TA]$@AUDP)
MYDR+I"1H`0``20'$30'@38GL3`'&38GH2<'L&TG!X`5-">!&C20&38GP2<'N
M`DG!X!Y-"?!-"<)-B<9$B<9)(=9-(>I-"?),B[0D<`$``$D!QDP!\4V)YDD!
MRDR)X4G![AM(P>$%3`GQ18TT"DR)Z4G![0)(P>$>3`GI38G%08G*20G-32'E
M32'030GH3(NL)'@!``!)`<5,`>I-B?5)`=!,B?))P>T;2,'B!4P)ZD6-+!!,
MB>)(P>(>2<'L`DP)XD@)T4F)U$&)T$TAU$PA\4P)X4R+I"2``0``20'$3`'F
M38GL2`'Q3(GN2<'L&TC!Y@5,">9$C20Q3(GV2<'N`DC!YAY,"?9)B=:)\4D)
M]DTA[D@ARDP)\DR+M"2(`0``20'&30'R38GF3`'238GB2<'N&TG!X@5-"?)&
MC30238GJ2<'M`DG!XAY-">I,"=9-B=5$B=))(<U,(>9,">Y,BZPDD`$``$D!
MQ4T!Z$V)]4P!QDV)\$G![1M)P>`%30GH1HTL!DV)X$G![`))P>`>30G@38G4
M1(G&30G$32'T22'R30GB3(ND))@!``!)`<1,`>%-B>Q)`<I,B>E)P>P;2,'A
M!4P)X46-)`I,B?%)P>X"2,'A'DP)\4D)R$F)SD&)RDDA]DTAZ$T)\$R+M"2@
M`0``20'&3`'R38GF20'03(GB2<'N&TC!X@5,"?)%C3003(GJ2,'B'DG![0),
M">I)B<U!B=!)"=5-(>5,(<%,">E,BZPDJ`$``$D!Q4P![DV)]4@!\4R)]DG!
M[1M(P>8%3`GN1(TL,4R)YDG![`)(P>8>3`GF2`GR28GTB?%-(<1,(?),">),
MBZ0DL`$``$D!Q$T!XDV)[$P!TDV)ZDG![!M)P>(%30GB38GT2<'N`DG!Y!Y!
M`=)-"?1)B?9$B>)-">9-(>Y((=9,"?9,B[0DN`$``$D!QDT!\$V)UDP!QDV)
MT$G![AM)P>`%30GP1HT\!DV)Z$G![0))P>`>30GH30G$38G%1(G&22'532'4
M30GL3(NL),`!``!)`<5,`>E-B?U)`<Q,B?E)P>T;2,'A!4P)Z4$!S$R)T4G!
MZ@)(P>$>3`G138G"08G.20G*32'Z32'P30G03(N4),@!``!)`<),`=)-B>))
M`=!,B>)(P>(%2<'J&TP)TDV)^DG![P))P>(>18TL$$T)^DP)T4R)TD6)UTPA
M\DPAX4@)T4B+E"30`0``2`'"2`'63(GJ2`'Q3(GN2,'B!4C![AM("?),B>9)
MP>P"2,'F'D2-!!%(BY0DV`$``$R)T4P)YD&)]$@)\4@!PDPAZ4TAXDP!\DD)
MRDR)P4D!TDR)PDC!Z1M(P>(%2`G*3(GI2<'M`HG22,'A'DP!TDP)Z4@#A"3@
M`0``2`G.28G-08G208G.3"'&32'E20GU2HTT.$R)P$G!Z`)(P>`>20'U38G7
M3(G62<'O&TD)P$C!Y@6XUL%BRDPQP4P)_DV)QT6)P#'*2(N,).@!``")]DP!
M[D@!P4&)]4D!S$J-#")-B>Q,B>I(P>H;2<'D!4D)U$R)TDG!Z@)(P>(>18GD
M20G22(N4)/`!``!)`<Q-,==$B>%(`<)$,?Y)`=9(B<I,`?9)B<Y(P>(%2<'N
M&TP)\HG23(TT%DR)ZDG![0)(P>(>18GW20G52(N4)/@!``!(`<)*C30"38G0
M3(GZ18G233'H2,'J&T4QQ$Z-!"9-B?Q)P>0%20G42(G*2,'I`DC!XAY%B>1(
M"<I(BXPD``(``$T!Q$6)X$@!P4R)QDP!T4V)ZD6)[4DQTD4QUDZ-%#%-B<9,
MB<%(P>D;2<'F!4D)SDR)^4G![P)(P>$>18GV20G/2(N,)`@"``!-`=9%B?)(
M`<%,`>E)B=6)TDTQ_44Q[$Z-+"%-B=1,B=%(P>D;2<'D!4D)S$B+C"00`@``
M18GD30'L2<'H`D@!P4C!YAY(`=%,B?I%B>5,"<9%B?](,?)!,=9*C10Q38GN
M3(GI2,'I&TG!Y@5)"<Y,B>E)P>T"18GV2,'A'DD!UDR)TDG!Z@),">E(P>(>
M18GP20G22(N4)!@"``!(`<),`?I)B?>)]DTQUT4Q_$Z-/")-B<1,B<)(P>H;
M2<'D!4D)U$B+E"0@`@``18GD2`'"30'\3(TL,DR)UD6)YT6)TD@QSDR)^D$Q
M]DC!ZAM+C70U`$V)_DG!Y@5)"=9,B<)%B?9)`?9(P>(>2(NT)#`"``!)P>@"
M18GU20G02(N4)"@"``!(`<9(`<),`=))B<J)R4TQPD4QU$Z-%")-B>Q,B>I(
MP>H;2<'D!4D)U$R)^DG![P)(P>(>18GD3`GZ3(T\#DR)P4T!U$@QT46)XD6)
MP$$QSDR)UDN-##=-B=9(P>X;2<'F!4D)]DR)UD6)]DD!SDR)Z4G![0)(P>$>
M18GW20G-2(N,)#@"``!(`<%,`<%)B=")TDTQZ$4QQ$Z-!"%-B?Q,B?E(P>D;
M2<'D!4D)S$B+C"1``@``18GD30'$2`'!2<'J`DC!YAY%B>!,"=9,C1013(GJ
M3(G!2#'R2,'I&T6)[4$QUDN-%#)-B<9)P>8%20G.3(G!2<'H`D6)]DC!X1Y)
M`=9,B?I)P>\"3`G!2,'B'D6)\DD)UTB+E"1(`@``2`'"3`'J28GUB?9-,?U%
M,>Q.C2PB38G43(G22,'J&TG!Y`5)"=1(BY0D4`(``$6)Y$@!PDT![$R-!#),
MB?Y%B>5%B?](,<Y,B>I!,?9(P>H;2XTT,$V)[DG!Y@5)"=9,B=)%B?9)`?9(
MP>(>2(NT)&`"``!)P>H"18GP20G22(N4)%@"``!(`<9(`<))`==(B<J)R4PQ
MTD$QU$R)PDT!_$V)QTC!ZAM)P><%20G73(GJ2<'M`DC!XAY%B?],">I,C2P.
M3(G130'\2#'118GG18G203'.3(G^2XU,-0!-B?Y(P>X;2<'F!4D)]D6)]DD!
MSDR)P4G!Z`)(P>$>1(GV20G(2(N,)&@"``!(`<%)`<I(B=&)TDPQP4$QS$B)
M\4T!U$F)\DC!Z1M)P>(%20G*3(GY2<'O`DC!X1Y%B=))"<](BXPD<`(``$T!
MXD6)U$@!P4R-+!%,B<),B>%%B<!,,?I(P>D;03'62XU4-0!-B>9)P>8%20G.
M18GV20'62(GR2,'N`DC!XAY$B?%("=9(BY0D>`(``$@!PD@#A"2``@``20'0
M3(GZ20'!18G_2#'R2(GP30'/03'22(G*30'028G*2,'B!4G!ZAM,"=)!`=!,
MB>))P>P"2,'B'DV)P4D)U$R)PDPQX$$QQDG!X05!`>A!`=Q(P>H;2XT$-P-W
M($R)1PA)"=%,B6<800'!2(G(2,'I`DB)=R!(P>`>3(D/2`G!00'+3(E?$$B+
MA"2(`@``9$@K!"4H````=`7H3]/__TB!Q)@"``!;74%<05U!7D%?PU"_@```
M`.CBT/__NHFKS>^Y_MRZF+[PX=+#2,<``2-%9TB)4`A(B4@02,=`&'94,A!(
MB7`@2,=`*`````!(QT`P`````,=`>`````!:PT%62&/"055!5%5(B<532(M/
M*$B)^XT4P4@YT78$2/]',$C!Z!U(`4,P2&-#>$R-8SA(B5,HA<!T3[I`````
M*<(YU0].U4P!X$ACRD@Y\',+2(T\"$@Y_G,"#PM,C2P.2#GP=@5,.>AR\$B)
MQ_.DBT-X`=")0WB#^$!U<TB)WRG5Z`GI__],B>Y,C6MX@_T_?C),.>9V!4PY
M[G*^3(UV0$DY]'8%33GT<K"Y$````$R)YX/M0/.E2(G?Z-#H__],B?;KR4AC
MS4PYYG8)28T$#$@YQG*%3#GF<PU(C00.23G$#X)S____3(GG\Z2):WA;74%<
M05U!7L-!5DR-=CA!54%454B)]5-(BT8H2(G[1(MF*$2+;C!(P>@#@^`_00_,
M00_-C7`!2)A(8];&1`4X@$P!\H/^.'XDN4`````QP$B)URGQ\ZI(B>_H0>C_
M_[D.````,<!,B??SJ^L.N3@````QP$B)URGQ\ZI$B6UP2(GO1(EE=.@5Z/__
M2(M%`$B)[TC!Z!B(`TB+10!(P>@0B$,!2(M%`$C!Z`B(0P)(BT4`B$,#2(M%
M"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10A(P>@(B$,&2(M%"(A#!TB+11!(P>@8
MB$,(2(M%$$C!Z!"(0PE(BT402,'H"(A#"DB+11"(0PM(BT482,'H&(A##$B+
M11A(P>@0B$,-2(M%&$C!Z`B(0PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@2,'H
M$(A#$4B+12!(P>@(B$,22(M%((A#$UM=05Q!74%>Z1_0__]F+@\?A```````
M#Q]$``!(BP59:0``2(/X_W0S54B)Y5-(C1U':0``2(/L"`\?`/_02(M#^$B#
MZPA(@_C_=?!(BUWXR<-F+@\?A```````PU#HZ=+__UC#````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````4$%27U1-4$1)4@!414U01$E2`%1-4``N+@`E<R\E<P!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE
M`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,
M24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'
M3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27T=,3T)!3%]414U0
M`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%4
M2`!365-414T`+W1M<`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E
M<P`E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D52
M4TE/3@`Q+C`U,@!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E
M<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*`"UE`"TM`&5V86P@)V5X96,@+W5S<B]B:6XO
M<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N
M9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'
M24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q
M,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I>F4I
M('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE("4@
M)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D;3L*
M?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4["GT*
M=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC7W!O
M<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA9VEC
M7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@/"`P
M.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D8G5F
M+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB+"`D
M8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI
M<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&
M24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q
M6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H
M("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD
M968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I
M/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D
M8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD
M("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@
M/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R
M8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@
M)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE
M.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5](&]R
M(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U
M;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL
M93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@
M9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D
M92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P
M*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T
M('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U:65T
M(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P
M:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@
M=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*0W)E
M871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L
M"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\
M($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T
M(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E
M:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A7W!O
M<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6
M>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO
M*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X["F-L
M;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET=&5N
M(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F
M:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*)&9H
M+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@
M87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3
M:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.
M5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@
M(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE
M;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$
M:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH
M/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*
M8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]
M"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE
M(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=
M(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M
M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I
M(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI
M.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E
M($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0[
M"G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&
M8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/
M.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z
M.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R
M:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@
M5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@
M>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q
M=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER
M92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E
M<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN
M960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI
M+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A
M=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN
M97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@
M)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED
M*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE
M9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ
M3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA
M;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!
M345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^
M(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM
M?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B
M=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X
M+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@
M>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$["FUY
M("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ
M<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA
M;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T
M>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS
M92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG
M>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE(&]R
M(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2
M(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E
M("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'
M3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N
M+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q
M(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T
M<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO
M9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN
M:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I
M;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@
M<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE
M>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S
M8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<
M;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE
M>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*
M`````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P
M97)L>'-I+F,````!&P,[X````!L```"D@?___````!2%__\D`0``-(7__\0$
M``!YB/__/`$```*)__^$`0``.HG__YP!``"HB?__Q`$``-V*__\(`@``7XO_
M_R0"``#[C/__:`(``":-__^``@``:HW__Y@"``!5CO__S`(``%J.___@`@``
M^H___RP#```0D/__0`,``+J0__]D`P``69+__X`#``"ADO__F`,``+B2__^P
M`P``0I/__^@#```(F?__9`0``$2;__^0!```DYO__^P$``"WL?__.`4```6R
M__]0!0``_++__XP%```4``````````%Z4@`!>!`!&PP'")`!```D````'```
M`*"`__]P`P````X01@X82@\+=PB``#\:.RHS)"(`````%````$0```#H@___
M&```````````````1````%P````UA___B0````!"#A"/`D(.&(X#0@X@C01"
M#BB,!40.,(8&00XX@P=!#D`";0XX1`XP00XH0@X@0@X80@X00@X(%````*0`
M``!VA___.`````!$#B!S#@@`)````+P```"6A___;@````!!#A"&`D$.&(,#
M1PXP`F(.&$$.$$$."$````#D````W(?__S4!````0@X0C@)"#AB-`T(.((P$
M00XHA@5!#C"#!D<.T`$#'0$.,$$.*$$.($(.&$(.$$(."```&````"@!``#-
MB/__@@````!'#L`!`GH."````$````!$`0``,XG__YP!````0@X0C@)"#AB-
M`T(.((P$00XHA@5$#C"#!D<.0`.!`0XP00XH00X@0@X80@X00@X(````%```
M`(@!``"+BO__*P````!!#A!4#@@`%````*`!``">BO__1`````!!#A!J#@@`
M,````+@!``#*BO__ZP````!"#A",`D$.&(8#00X@@P1'#K!``ML.($$.&$$.
M$$(."````!````#L`0``@8O__P4`````````2``````"``!RB___H`$```!"
M#A"/`D(.&(X#0@X@C01,#BB,!4$.,(8&1`XX@P='#N`A`W0!#CA$#C!!#BA"
M#B!"#AA"#A!"#@@``!````!,`@``QHS__Q8`````````(````&`"``#(C/__
MJ@````!*#A"&`@),"L8."$(+`D4."$'&&````(0"``!.C?__GP$```!$#D`#
MF@$."````!0```"@`@``T8[__T@`````2@X0=@X(`!0```"X`@```8___Q<`
M````00X050X(`#0```#0`@```(___XH`````0@X0C`)-#AB&`T$.((,$`F0*
M#AA(#A!$#@A%"T$.&$$.$$(."```>`````@#``!2C___Q@4```!"#A"/`DX.
M&(X#0@X@C01"#BB,!4$.,(8&00XX@P=*#I"#`@*;"@XX1`XP00XH0@X@0@X8
M0@X00@X(10L#C@0.F(,"2@Z@@P)0#IB#`D$.D(,"`D(..$0.,$$.*$(.($(.
M&$(.$$(."````"@```"$`P``G)3__SP"````0@X0C`)'#AB&`T$.((,$`RX"
M#AA!#A!"#@@`,````+`#``"LEO__3P````!!#A"&`D0.&(,#00X@>PH.&$0.
M$$$."$4+00X800X000X(`"0```#D`P``:(#__ZL!````0@X0C`)$#C`#GP$.
M$$4."`````````!(````#`0``)^6__\D%@```$(.$(\"1`X8C@-"#B"-!$(.
M*(P%00XPA@9!#CB#!T<.T`4#!A8..$$.,$$.*$(.($(.&$(.$$(."```%```
M`%@$``!WK/__3@````!!#A`"3`X(.````'`$``"MK/__]P````!"#A".`D4.
M&(T#0@X@C`1!#BB&!40.,(,&`N$.*$$.($(.&$(.$$(."```.````*P$``!H
MK?__60$```!"#A".`D8.&(T#0@X@C`1!#BB&!40.,(,&`SX!#BA!#B!"#AA"
M#A!"#@@`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````/__________``````````#_____
M_____P`````````````````````!`````````-H"`````````0````````#E
M`@````````\`````````$`0````````,```````````@````````#0``````
M```14P```````/7^_V\`````,`,````````%`````````!`-````````!@``
M```````H!`````````H`````````+@0````````+`````````!@`````````
M%0````````````````````,`````````^+T````````"`````````!`%````
M````%``````````'`````````!<`````````"!,````````'`````````$`1
M````````"`````````#(`0````````D`````````&``````````8````````
M````````````^___;P`````!```(`````/G__V\`````!P``````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````%B\````````````````
M`````````````"8@````````-B````````!&(````````%8@````````9B``
M``````!V(````````(8@````````EB````````"F(````````+8@````````
MQB````````#6(````````.8@````````]B`````````&(0```````!8A````
M````)B$````````V(0```````$8A````````5B$```````!F(0```````'8A
M````````AB$```````"6(0```````*8A````````MB$```````#&(0``````
M`-8A````````YB$```````#V(0````````8B````````%B(````````F(@``
M`````#8B````````1B(```````!6(@```````&8B````````=B(```````"&
M(@```````)8B````````IB(```````"V(@```````,8B````````UB(`````
M``#F(@```````/8B````````!B,````````6(P```````"8C````````-B,`
M``````!&(P```````%8C````````9B,```````!V(P``````````````````
M````````````````````````````````````````````````````````````
M````````````````P`````````````````````````````````````````!@
M````````\F`````````+8`````````1A````````$V``````````````````
M`/____\`````MF(```````!'0T,Z("A!;'!I;F4@,3`N,RXQ7V=I=#(P,C$P
M.3(Q*2`Q,"XS+C$@,C`R,3`Y,C$``"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E
M+F=N=2YP<F]P97)T>0`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR96QA
M+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD
M871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````X`(```````#@`@``````
M`!D````````````````````!````````````````````$P````<````"````
M```````#``````````,````````P````````````````````"```````````
M`````````"8```#V__]O`@`````````P`P```````#`#````````^```````
M```$``````````@````````````````````P````"P````(`````````*`0`
M```````H!````````.@(````````!0````$````(`````````!@`````````
M.`````,````"`````````!`-````````$`T````````N!```````````````
M`````0```````````````````$`````$`````@````````!`$0```````$`1
M````````R`$````````$``````````@`````````&`````````!*````!```
M`$(`````````"!,````````($P```````!`%````````!````!0````(````
M`````!@`````````5`````$````&```````````@`````````"`````````-
M`````````````````````0```````````````````$\````!````!@``````
M```0(````````!`@````````<`,``````````````````!``````````$```
M``````!:`````0````8`````````@",```````"`(P```````!@`````````
M```````````(``````````@`````````8P````$````&`````````*`C````
M````H",```````!Q+P``````````````````$````````````````````&D`
M```!````!@`````````14P```````!%3````````"```````````````````
M``$```````````````````!O`````0````(``````````&``````````8```
M`````&H^```````````````````(````````````````````=P````$````"
M`````````&R>````````;)X```````#D````````````````````!```````
M`````````````(4````!`````@````````!0GP```````%"?````````Z`0`
M``````````````````@```````````````````"/`````0````,`````````
M,+P````````PK````````!`````````````````````(````````````````
M````E@````$````#`````````$"\````````0*P````````0````````````
M````````"````````````````````)T````!`````P````````!0O```````
M`%"L````````"````````````````````!````````````````````"J````
M!@````,`````````6+P```````!8K````````*`!````````!0`````````(
M`````````!``````````7@````$````#`````````/B]````````^*T`````
M```(`@``````````````````"``````````(`````````+,````!`````P``
M````````P`````````"P````````8````````````````````"``````````
M``````````"Y````"`````,`````````8,````````!@L````````,`0````
M```````````````@````````````````````O@````$````P````````````
M````````8+`````````Q`````````````````````0`````````!````````
M``$````#`````````````````````````)&P````````QP``````````````
4``````$`````````````````````
